#
# spec file for package python-scikit-image
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


# Test discovery issues
%bcond_with tests

%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%define oldpython python
Name:           python-scikit-image
Version:        0.13.1
Release:        lp151.2.4
Summary:        Collection of algorithms for image processing in Python
License:        BSD-3-Clause
Group:          Productivity/Scientific/Other
Url:            http://scikit-image.org/
Source0:        https://files.pythonhosted.org/packages/source/s/scikit-image/scikit-image-%{version}.tar.gz
BuildRequires:  %{python_module Cython >= 0.23}
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module numpy-devel >= 1.11}
BuildRequires:  %{python_module scipy >= 0.17}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module six >= 1.7.3}
BuildRequires:  fdupes
BuildRequires:  freeimage-devel
BuildRequires:  python-rpm-macros
%if %{with tests}
BuildRequires:  %{python_module nose}
BuildRequires:  %{python_module pytest}
# Runtime dependencies
BuildRequires:  %{python_module Pillow >= 2.1.0}
BuildRequires:  %{python_module PyWavelets >= 0.4.0}
BuildRequires:  %{python_module matplotlib >= 1.3.1}
BuildRequires:  %{python_module networkx >= 1.8}
%endif
Requires:       python-Pillow >= 2.1.0
Requires:       python-PyWavelets >= 0.4.0
Requires:       python-matplotlib >= 1.3.1
Requires:       python-networkx >= 1.8
Requires:       python-numpy >= 1.11
Requires:       python-scipy >= 0.17
Requires:       python-six >= 1.7.3
Recommends:     python-pyamg
Recommends:     python-SimpleITK
Recommends:     python-astropy
Recommends:     python-dask-array >= 0.5.0
Recommends:     python-imread
Recommends:     python-qt4
%ifpython2
Provides:       %{oldpython}-scikits-image = %{version}
Obsoletes:      %{oldpython}-scikits-image < %{version}
%endif
Requires(post): update-alternatives
Requires(preun): update-alternatives
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%python_subpackages

%description
Scikit-image is a collection of algorithms for image processing in Python.
It is available free of charge and free of restriction.

%prep
%setup -q -n scikit-image-%{version}

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitearch}

%python_clone -a %{buildroot}%{_bindir}/skivi

%post
%python_install_alternative skivi

%preun
%python_uninstall_alternative skivi

%if %{with tests}
%check
mkdir tester
pushd tester
%{python_expand export PYTHONPATH=%{buildroot}%{$python_sitearch}
py.test-%{$python_bin_suffix} -v skimage
}
popd
rm -r tester
%endif

%files %{python_files}
%defattr(-,root,root)
%doc CONTRIBUTORS.txt LICENSE.txt TASKS.txt TODO.txt
%python_alternative %{_bindir}/skivi
%{python_sitearch}/skimage/
%{python_sitearch}/scikit_image-%{version}-py*.egg-info

%changelog
* Sat Sep 30 2017 arun@gmx.de
- update to version 0.13.1:
  * no upstream changelog available for 0.13.1
- 0.13.0 changelog available at: https://github.com/scikit-image/scikit-image/blob/master/doc/release/release_0.13.rst
* Mon Jun 12 2017 toddrme2178@gmail.com
- Implement single-spec version
- Update source URL
- Update to version 0.13.0
  * No upstream changelog
* Mon Jan 11 2016 toddrme2178@gmail.com
- update to version 0.11.3:
  (no changelog entry, taken from git log)
  * Fix handling of non-gif and tiff files
  * Fix setup to allow installing from PyPI
  * Fix support for Sphinx 1.3
  * Add a helper function to check for low contrast
  * Fix RANSAC for invalid model estimation and confidence corner case
- Fix update-alternatives usage
* Sat Nov 23 2013 p.drouand@gmail.com
- Missing 0.9.3 tarball in previous commit; upload it and remove old
  tarball
* Mon Oct 21 2013 toddrme2178@gmail.com
- Update to 0.9.3
  * No upstream changelog
- Rename to python-scikit-image to match new naming policy
* Sat Oct 13 2012 Angelos Tzotsos <tzotsos@opensuse.org>
- update version to 0.7.0
* Sun Mar 11 2012 Angelos Tzotsos <tzotsos@opensuse.org>
- initial OBS Build (v0.5.0)
